@@ -2,5 +2,5 @@ from pyconfita.backend.environment.environment import Backend as EnvBackend
 from pyconfita.backend.vault.vault import Backend as VaultBackend
 from pyconfita.backend.file.file import Backend as FileBackend
 from pyconfita.backend.dict.dict import Backend as DictBackend
-from pyconfita.logging_interface import LoggingInterface
+from pyconfita.logging_interface import LoggingInterface, DummyLoggingInterface
 from pyconfita.pyconfita import Confita
