@@ -1,5 +1,6 @@
 import os
 from typing import Optional, Any
+
 import yaml
 
 from pyconfita.backend.backend import Backend as _Backend
@@ -7,8 +8,9 @@ from pyconfita.backend.backend import Backend as _Backend
 
 class Backend(_Backend):
     """
-    Load value from file. WARNING: YAML support only!
-    File extension must be in ['.yaml', '.yml']
+    Load key from file.
+    WARNING: YAML support only!
+    Extensions must be in ['.yaml', '.yml']
     """
 
     name = "file"
